@@ -106,7 +106,7 @@ def main():
             capath=args.capath,
             cert=args.cert,
             key=args.key,
-            retries=args.retries
+            retries=int(args.retries)
         )
 
     server.run()
