@@ -39,7 +39,7 @@ class Server(object):
                  client_id=None, topics_subscription=None, mqtt_channel_name=None,
                  mqtt_channel_sub=None, mqtt_channel_pub=None, cafile=None, capath=None,
                  cert=None, key=None, retries=0):
-        self.retries = retries
+        self.retries = retries or 0
         self.channel = channel
         self.host = host
         self.port = port
@@ -65,7 +65,7 @@ class Server(object):
         self.mqtt_channel_pub = mqtt_channel_pub or "mqtt.pub"
         self.mqtt_channel_sub = mqtt_channel_sub or "mqtt.sub"
 
-        if capath or cafile or key or cert:
+        if capath or cafile or key or cert or port == 8883:
             self.client.tls_set(ca_certs=capath, certfile=cafile, keyfile=key, cert_reqs=cert)
 
     def _on_connect(self, client, userdata, flags, rc):
@@ -76,17 +76,18 @@ class Server(object):
     def _on_disconnect(self, client, userdata, rc):
         logger.info("Disconnected")
         if not self.stop:
-            reconnection = self.retries
-            while self.retries == 0 or reconnection > 0:
+            while self.retries >= 0:
                 logger.info("Trying to reconnect")
                 try:
                     client.reconnect()
                     logger.info("Reconnected")
                     break
                 except Exception as e:
-                    if self.retries == 0 or reconnection > 0:
-                        if reconnection > 0:
-                            reconnection -= 1
+                    if self.retries >= 0:
+                        if self.retries == 1:
+                            self.retries = -1
+                        elif self.retries > 0:
+                            self.retries -= 1
                         logger.warning(e)
                         time.sleep(1)
                         continue
